import { FoundationElement } from '@microsoft/fast-foundation';
import { MultiselectDatasource } from '../options-datasource';
import { Position } from './multiselect-consts';
export declare const foundationMultiselectShadowOptions: ShadowRootInit;
export declare const defaultMultiselectConfig: {};
export type MultiselectOption = {
    value: string;
    label: string;
    disabled?: boolean;
} | string;
/**
 * @tagname %%prefix%%-multiselect
 */
export declare class Multiselect extends FoundationElement {
    name: string;
    autoPosition: boolean;
    all: boolean;
    allSelected: boolean;
    search: boolean;
    disabled: boolean;
    async: boolean;
    debounce: number;
    debounceChanged(oldValue: any, newValue: number): void;
    debouncedInputHandler: any;
    defaultSlottedNodes: Node[];
    slottedDatasource: MultiselectDatasource[];
    valueFormatter: any;
    loading: boolean;
    filterSearchValue: string;
    private clickOutside;
    open: boolean;
    openChanged(previous: boolean, open: boolean): void;
    options: MultiselectOption[];
    selectedOptions: string[];
    filteredAvailableOptions: MultiselectOption[];
    scrollContainer: HTMLElement;
    /**
     * Controls the positioning of the multiselect dropdown. Accepts the following values:
     * - Position.ABOVE: Forces the dropdown to always open above the input field.
     * - Position.BELOW: Forces the dropdown to always open below the input field.
     */
    position: Position;
    onAllSelectedCallback: (allSelected: boolean) => void;
    private initialisedOptions;
    arrowIcon: SVGElement;
    optionsElement: HTMLElement;
    connectedCallback(): void;
    disconnectedCallback(): void;
    toggle(): void;
    optionsChanged(): void;
    selectedOptionsChanged(): void;
    /**
     * Sets the dropdown position based on the current configuration.
     * @remarks
     * If `autoPosition` is `true`, this method calculates the available space above and below the input field in the viewport and positions the dropdown accordingly.
     * This ensures the dropdown is always visible to the user. If `autoPosition` is `false`, the dropdown position is locked to either 'above' or 'below', as specified by the `position` attribute.
     * This method is intended for internal use by the component and is marked as private.
     * @private
     */
    private setDropdownPosition;
    optionGetter(option: MultiselectOption): string;
    getItemLabel(option: MultiselectOption): any;
    isOptionDisabled(option: MultiselectOption): boolean;
    get getDisplayValue(): string;
    get getPlaceholder(): string;
    get isAllSelected(): boolean;
    get isAllOptionsDisabled(): boolean;
    isOptionSelected(normalizedOption: MultiselectOption): boolean;
    selectCheckboxOne(normalizedOption: MultiselectOption): void;
    getEnabledOptionsCount(): number;
    selectCheckboxAll(): void;
    inputHandler(): void;
    setFilter(): void;
    asyncSetFilter(): void;
    changeHandler(event: Event): void;
    private handleClickOutside;
}
export declare const foundationMultiselect: (overrideDefinition?: import("@microsoft/fast-foundation").OverrideFoundationElementDefinition<{
    baseName: string;
    template: import("@microsoft/fast-element").ViewTemplate<Multiselect, any>;
    styles: import("@microsoft/fast-element").ElementStyles;
    shadowOptions: ShadowRootInit;
}>) => import("@microsoft/fast-foundation").FoundationElementRegistry<{
    baseName: string;
    template: import("@microsoft/fast-element").ViewTemplate<Multiselect, any>;
    styles: import("@microsoft/fast-element").ElementStyles;
    shadowOptions: ShadowRootInit;
}, typeof Multiselect>;
//# sourceMappingURL=multiselect.d.ts.map