import { __awaiter, __decorate } from "tslib";
import { FoundationAnalytics, FoundationAnalyticsEventType, } from '@genesislcap/foundation-comms';
import { customElement, DOM, FASTElement, observable, } from '@microsoft/fast-element';
import { Container } from '@microsoft/fast-foundation';
import { RouteCollection, Router, RouterConfiguration, } from '@microsoft/fast-router';
import { defaultNavItemPredicate, getNavItems } from './navItems';
/**
 * @internal
 */
const routerProperty = '$router';
/**
 * @beta
 * @privateRemarks
 * Created to patch an issue and act as a placeholder to improve the api ahead of upgrading to the latest. Depending on
 * how much we build on this, we may want to promote it to its own package.
 */
let FoundationRouter = class FoundationRouter extends Router.from(FASTElement) {
    connectedCallback() {
        super.connectedCallback();
        /**
         * Tactical patch for Safari 16
         * {@link https://genesisglobal.atlassian.net/browse/PA-226}
         *
         * Explicitly set the config on the $router property when we connect to the DOM.
         */
        DOM.queueUpdate(() => __awaiter(this, void 0, void 0, function* () {
            this[routerProperty].config = this.config;
        }));
    }
};
FoundationRouter = __decorate([
    customElement({
        name: 'foundation-router',
    })
], FoundationRouter);
export { FoundationRouter };
/**
 * @beta
 */
export class FoundationRouteCollection extends RouteCollection {
    constructor() {
        super(...arguments);
        this.definitions = [];
    }
    map(...routes) {
        this.definitions = [...this.definitions, ...routes];
        super.map(...routes);
    }
}
__decorate([
    observable
], FoundationRouteCollection.prototype, "definitions", void 0);
/**
 * @beta
 */
export class FoundationRouterConfiguration extends RouterConfiguration {
    constructor() {
        super(...arguments);
        this.routes = new FoundationRouteCollection(this);
    }
    /**
     * @remarks
     * Get navigation items from the route definitions.
     */
    getNavItems(predicate = defaultNavItemPredicate) {
        return getNavItems(this.routes.definitions, predicate);
    }
    /**
     * @remarks
     * Applies the analytics service to the navigate phase.
     */
    configureAnalytics() {
        this.contributors.push({
            navigate: (phase) => __awaiter(this, void 0, void 0, function* () {
                this.analytics.trackEvent(FoundationAnalyticsEventType.routeChanged, {
                    path: phase.route.endpoint.path,
                });
            }),
        });
    }
    construct(Type) {
        return this.container.get(Type);
    }
}
__decorate([
    Container
], FoundationRouterConfiguration.prototype, "container", void 0);
__decorate([
    FoundationAnalytics
], FoundationRouterConfiguration.prototype, "analytics", void 0);
